==> haskell-socks-0.6.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.6.0
id: socks-0.6.0-Gul7CfHitLf4p1upRUfbGQ
key: socks-0.6.0-Gul7CfHitLf4p1upRUfbGQ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: 01d48ca8ddfc62248a7fc076e17e683d
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/socks-0.6.0
hs-libraries: HSsocks-0.6.0-Gul7CfHitLf4p1upRUfbGQ
depends:
    base-4.12.0.0 basement-0.0.11-C095fEhcIb5E8Z5F95kg3I
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    network-2.8.0.0-5u6ySGtGxtsHs1Xy660chH
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-socks-0.6.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: socks
version: 0.6.0
id: socks-0.6.0-ENn9ZJmj6xMKq3jsmgo1j0
key: socks-0.6.0-ENn9ZJmj6xMKq3jsmgo1j0
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-socks
synopsis: Socks proxy (ver 5)
description:
    Socks proxy (version 5) implementation.
category: Network
abi: cedf0eeaae9d87f577bd0cc90ea5d493
exposed: True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types
hidden-modules: Network.Socks5.Wire Network.Socks5.Conf
                Network.Socks5.Command Network.Socks5.Parse
import-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/socks-0.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/socks-0.6.0
hs-libraries: HSsocks-0.6.0-ENn9ZJmj6xMKq3jsmgo1j0
depends:
    base-4.12.0.0 basement-0.0.11-C095fEhcIb5E8Z5F95kg3I
    bytestring-0.10.8.2 cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
haddock-interfaces: /usr/share/doc/haskell-socks/html/socks.haddock
haddock-html: /usr/share/doc/haskell-socks/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
